aboutsummaryrefslogtreecommitdiff
path: root/scumm
diff options
context:
space:
mode:
authorTravis Howell2005-06-13 07:09:12 +0000
committerTravis Howell2005-06-13 07:09:12 +0000
commitae7f676667d3762d5fb2ca1b49dcf4cb4b7f3bc3 (patch)
treec95798763f36e969f7e183da6d146900299f97bc /scumm
parentdcbd7775960f8fc96318bef98e61d30241815ca8 (diff)
downloadscummvm-rg350-ae7f676667d3762d5fb2ca1b49dcf4cb4b7f3bc3.tar.gz
scummvm-rg350-ae7f676667d3762d5fb2ca1b49dcf4cb4b7f3bc3.tar.bz2
scummvm-rg350-ae7f676667d3762d5fb2ca1b49dcf4cb4b7f3bc3.zip
Rename opcode/function
svn-id: r18381
Diffstat (limited to 'scumm')
-rw-r--r--scumm/intern.h2
-rw-r--r--scumm/script_v100he.cpp2
-rw-r--r--scumm/script_v6.cpp4
-rw-r--r--scumm/script_v6he.cpp2
-rw-r--r--scumm/script_v72he.cpp2
-rw-r--r--scumm/script_v7he.cpp2
-rw-r--r--scumm/script_v8.cpp2
-rw-r--r--scumm/script_v80he.cpp2
-rw-r--r--scumm/script_v90he.cpp2
-rw-r--r--scumm/scumm.h2
-rw-r--r--scumm/string.cpp8
11 files changed, 15 insertions, 15 deletions
diff --git a/scumm/intern.h b/scumm/intern.h
index a90d4e0b09..4226078bfd 100644
--- a/scumm/intern.h
+++ b/scumm/intern.h
@@ -678,7 +678,7 @@ protected:
void o6_delayMinutes();
void o6_stopSentence();
void o6_printLine();
- void o6_printCursor();
+ void o6_printText();
void o6_printDebug();
void o6_printSystem();
void o6_printActor();
diff --git a/scumm/script_v100he.cpp b/scumm/script_v100he.cpp
index 5654a7b713..b359ec8923 100644
--- a/scumm/script_v100he.cpp
+++ b/scumm/script_v100he.cpp
@@ -152,7 +152,7 @@ void ScummEngine_v100he::setupOpcodes() {
OPCODE(o6_printLine),
OPCODE(o6_printSystem),
/* 58 */
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o100_jumpToScriptUnk),
OPCODE(o100_startScriptUnk),
OPCODE(o6_pseudoRoom),
diff --git a/scumm/script_v6.cpp b/scumm/script_v6.cpp
index 02548ed5f8..986cf79cc4 100644
--- a/scumm/script_v6.cpp
+++ b/scumm/script_v6.cpp
@@ -275,7 +275,7 @@ void ScummEngine_v6::setupOpcodes() {
OPCODE(o6_stopSentence),
/* B4 */
OPCODE(o6_printLine),
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o6_printDebug),
OPCODE(o6_printSystem),
/* B8 */
@@ -2327,7 +2327,7 @@ void ScummEngine_v6::o6_printLine() {
decodeParseString(0, 0);
}
-void ScummEngine_v6::o6_printCursor() {
+void ScummEngine_v6::o6_printText() {
decodeParseString(1, 0);
}
diff --git a/scumm/script_v6he.cpp b/scumm/script_v6he.cpp
index a444a6397c..870ead68d9 100644
--- a/scumm/script_v6he.cpp
+++ b/scumm/script_v6he.cpp
@@ -294,7 +294,7 @@ void ScummEngine_v60he::setupOpcodes() {
OPCODE(o6_stopSentence),
/* B4 */
OPCODE(o6_printLine),
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o6_printDebug),
OPCODE(o6_printSystem),
/* B8 */
diff --git a/scumm/script_v72he.cpp b/scumm/script_v72he.cpp
index 1ab4f0620c..f48cca0205 100644
--- a/scumm/script_v72he.cpp
+++ b/scumm/script_v72he.cpp
@@ -270,7 +270,7 @@ void ScummEngine_v72he::setupOpcodes() {
OPCODE(o6_stopSentence),
/* B4 */
OPCODE(o6_printLine),
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o6_printDebug),
OPCODE(o6_printSystem),
/* B8 */
diff --git a/scumm/script_v7he.cpp b/scumm/script_v7he.cpp
index 69f384819a..e525aa6619 100644
--- a/scumm/script_v7he.cpp
+++ b/scumm/script_v7he.cpp
@@ -268,7 +268,7 @@ void ScummEngine_v70he::setupOpcodes() {
OPCODE(o6_stopSentence),
/* B4 */
OPCODE(o6_printLine),
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o6_printDebug),
OPCODE(o6_printSystem),
/* B8 */
diff --git a/scumm/script_v8.cpp b/scumm/script_v8.cpp
index 39c5248954..dc05fd1541 100644
--- a/scumm/script_v8.cpp
+++ b/scumm/script_v8.cpp
@@ -227,7 +227,7 @@ void ScummEngine_v8::setupOpcodes() {
OPCODE(o6_talkEgo),
OPCODE(o6_printLine),
/* 94 */
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o6_printDebug),
OPCODE(o6_printSystem),
OPCODE(o8_blastText),
diff --git a/scumm/script_v80he.cpp b/scumm/script_v80he.cpp
index 2969abe53f..1d54389c3a 100644
--- a/scumm/script_v80he.cpp
+++ b/scumm/script_v80he.cpp
@@ -270,7 +270,7 @@ void ScummEngine_v80he::setupOpcodes() {
OPCODE(o6_stopSentence),
/* B4 */
OPCODE(o6_printLine),
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o6_printDebug),
OPCODE(o6_printSystem),
/* B8 */
diff --git a/scumm/script_v90he.cpp b/scumm/script_v90he.cpp
index c48c4e9c34..a7b76647d0 100644
--- a/scumm/script_v90he.cpp
+++ b/scumm/script_v90he.cpp
@@ -269,7 +269,7 @@ void ScummEngine_v90he::setupOpcodes() {
OPCODE(o6_stopSentence),
/* B4 */
OPCODE(o6_printLine),
- OPCODE(o6_printCursor),
+ OPCODE(o6_printText),
OPCODE(o6_printDebug),
OPCODE(o6_printSystem),
/* B8 */
diff --git a/scumm/scumm.h b/scumm/scumm.h
index 05f49d1c66..cad36260d8 100644
--- a/scumm/scumm.h
+++ b/scumm/scumm.h
@@ -1154,7 +1154,7 @@ protected:
void CHARSET_1();
void drawString(int a, const byte *msg);
- void unkMessage1(const byte *msg);
+ void debugMessage(const byte *msg);
void showMessageDialog(const byte *msg);
int convertMessageToString(const byte *msg, byte *dst, int dstSize);
diff --git a/scumm/string.cpp b/scumm/string.cpp
index 0e0a79b5d5..620f3f3391 100644
--- a/scumm/string.cpp
+++ b/scumm/string.cpp
@@ -45,7 +45,7 @@ void ScummEngine::printString(int m, const byte *msg) {
drawString(1, msg);
break;
case 2:
- unkMessage1(msg);
+ debugMessage(msg);
break;
case 3:
showMessageDialog(msg);
@@ -54,11 +54,11 @@ void ScummEngine::printString(int m, const byte *msg) {
}
-void ScummEngine::unkMessage1(const byte *msg) {
+void ScummEngine::debugMessage(const byte *msg) {
byte buffer[500];
convertMessageToString(msg, buffer, sizeof(buffer));
-// if ((_gameId == GID_CMI) && _debugMode) { // In CMI, unkMessage1 is used for printDebug output
+// if ((_gameId == GID_CMI) && _debugMode) { // In CMI, debugMessage is used for printDebug output
if ((buffer[0] != 0xFF) && _debugMode) {
debug(0, "DEBUG: %s", buffer);
return;
@@ -330,7 +330,7 @@ void ScummEngine::CHARSET_1() {
a->startAnimActor(frme);
break;
case 10:
// Note the similarity to the code in unkMessage1()
talk_sound_a = buffer[0] | (buffer[1] << 8) | (buffer[4] << 16) | (buffer[5] << 24);
talk_sound_b = buffer[8] | (buffer[9] << 8) | (buffer[12] << 16) | (buffer[13] << 24);
buffer += 14;
@@ -330,7 +330,7 @@ void ScummEngine::CHARSET_1() {
break;
case 10:
- // Note the similarity to the code in unkMessage1()
+ // Note the similarity to the code in debugMessage()
talk_sound_a = buffer[0] | (buffer[1] << 8) | (buffer[4] << 16) | (buffer[5] << 24);
talk_sound_b = buffer[8] | (buffer[9] << 8) | (buffer[12] << 16) | (buffer[13] << 24);